# Step 3: Enrich Data
### On this page
  * [Datapoints for Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data#datapoints-for-rationalization)
  * [Collect Data from Experts](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data#collect-data-from-experts)
  * [Collect Data from Integrations](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data#collect-data-from-integrations)
  * [Total Cost of Ownership](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data#total-cost-of-ownership)
  * [Calculate the Total Cost of Ownership for Applications](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data#calculate-the-total-cost-of-ownership-for-applications)
  * [Allocate Application Cost](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data#allocate-application-cost)
  * [Custom Cost Calculations](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data#custom-cost-calculations)


Gather and enrich application data to enable data-driven rationalization decisions, use surveys and integrations to save time and improve data quality.
With the scoped list of applications, it's now time to look closely at your inventory and enrich the data in SAP LeanIX with the relevant attributes for the rationalization assessment.
Gathering this data can be time-consuming because you need to approach application owners and technical experts. Surveys and integrations can streamline your data collection process and reduce the time needed to achieve the required data quality.
